@@ -665,7 +665,7 @@ try_class (GIOExtension *extension,
  * The result is cached after it is generated the first time, and
  * the function is thread-safe.
  *
- * Return value: (transfer none): an object implementing
+ * Returns: (transfer none): an object implementing
  *     @extension_point, or %NULL if there are no usable
  *     implementations.
  */
@@ -788,7 +788,7 @@ try_implementation (GIOExtension         *extension,
  * The result is cached after it is generated the first time, and
  * the function is thread-safe.
  *
- * Return value: (transfer none): an object implementing
+ * Returns: (transfer none): an object implementing
  *     @extension_point, or %NULL if there are no usable
  *     implementations.
  */
@@ -1253,6 +1253,8 @@ g_io_extension_point_get_extension_by_name (GIOExtensionPoint *extension_point,
 {
   GList *l;
 
+  g_return_val_if_fail (name != NULL, NULL);
+
   lazy_load_modules (extension_point);
   for (l = extension_point->extensions; l != NULL; l = l->next)
     {
