@@ -113,6 +113,7 @@ G_BEGIN_DECLS
  * GParamFlags:
  * @G_PARAM_READABLE: the parameter is readable
  * @G_PARAM_WRITABLE: the parameter is writable
+ * @G_PARAM_READWRITE: alias for %G_PARAM_READABLE | %G_PARAM_WRITABLE
  * @G_PARAM_CONSTRUCT: the parameter will be set upon object construction
  * @G_PARAM_CONSTRUCT_ONLY: the parameter will only be set upon object construction
  * @G_PARAM_LAX_VALIDATION: upon parameter conversion (see g_param_value_convert())
@@ -142,6 +143,7 @@ typedef enum
 {
   G_PARAM_READABLE            = 1 << 0,
   G_PARAM_WRITABLE            = 1 << 1,
+  G_PARAM_READWRITE           = (G_PARAM_READABLE | G_PARAM_WRITABLE),
   G_PARAM_CONSTRUCT	      = 1 << 2,
   G_PARAM_CONSTRUCT_ONLY      = 1 << 3,
   G_PARAM_LAX_VALIDATION      = 1 << 4,
@@ -154,12 +156,6 @@ typedef enum
   /* User defined flags go up to 30 */
   G_PARAM_DEPRECATED          = 1 << 31
 } GParamFlags;
-/**
- * G_PARAM_READWRITE:
- * 
- * #GParamFlags value alias for %G_PARAM_READABLE | %G_PARAM_WRITABLE.
- */
-#define	G_PARAM_READWRITE	(G_PARAM_READABLE | G_PARAM_WRITABLE)
 /**
  * G_PARAM_STATIC_STRINGS:
  * 
@@ -196,7 +192,7 @@ typedef struct _GParamSpecPool  GParamSpecPool;
  * @value_type: the #GValue type for this parameter
  * @owner_type: #GType type that uses (introduces) this parameter
  * 
- * All other fields of the <structname>GParamSpec</structname> struct are private and
+ * All other fields of the GParamSpec struct are private and
  * should not be used directly.
  */
 struct _GParamSpec
@@ -230,8 +226,8 @@ struct _GParamSpec
  * @values_cmp: Compares @value1 with @value2 according to this type
  *  (recommended, the default is memcmp()), see g_param_values_cmp().
  * 
- * The class structure for the <structname>GParamSpec</structname> type.
- * Normally, <structname>GParamSpec</structname> classes are filled by
+ * The class structure for the GParamSpec type.
+ * Normally, GParamSpec classes are filled by
  * g_param_type_register_static().
  */
 struct _GParamSpecClass
@@ -258,7 +254,7 @@ struct _GParamSpecClass
  * @name: the parameter name
  * @value: the parameter value
  * 
- * The <structname>GParameter</structname> struct is an auxiliary structure used
+ * The GParameter struct is an auxiliary structure used
  * to hand parameter name/value pairs to g_object_newv().
  */
 struct _GParameter /* auxiliary structure for _setv() variants */
@@ -342,7 +338,7 @@ typedef struct _GParamSpecTypeInfo GParamSpecTypeInfo;
 /**
  * GParamSpecTypeInfo:
  * @instance_size: Size of the instance (object) structure.
- * @n_preallocs: Prior to GLib 2.10, it specified the number of pre-allocated (cached) instances to reserve memory for (0 indicates no caching). Since GLib 2.10, it is ignored, since instances are allocated with the <link linkend="glib-Memory-Slices">slice allocator</link> now.
+ * @n_preallocs: Prior to GLib 2.10, it specified the number of pre-allocated (cached) instances to reserve memory for (0 indicates no caching). Since GLib 2.10, it is ignored, since instances are allocated with the [slice allocator][glib-Memory-Slices] now.
  * @instance_init: Location of the instance initialization function (optional).
  * @value_type: The #GType of values conforming to this #GParamSpec
  * @finalize: The instance finalization function (optional).
