@@ -882,10 +882,14 @@ typedef void   (*GClassFinalizeFunc)         (gpointer         g_class,
  * A callback function used by the type system to initialize a new
  * instance of a type. This function initializes all instance members and
  * allocates any resources required by it.
+ *
  * Initialization of a derived instance involves calling all its parent
  * types instance initializers, so the class member of the instance
  * is altered during its initialization to always point to the class that
  * belongs to the type the current initializer was introduced for.
+ *
+ * The extended members of @instance are guaranteed to have been filled with
+ * zeros before this function is called.
  */
 typedef void   (*GInstanceInitFunc)          (GTypeInstance   *instance,
 					      gpointer         g_class);
@@ -897,6 +901,9 @@ typedef void   (*GInstanceInitFunc)          (GTypeInstance   *instance,
  * A callback function used by the type system to initialize a new
  * interface.  This function should initialize all internal data and
  * allocate any resources required by the interface.
+ *
+ * The members of @iface_data are guaranteed to have been filled with
+ * zeros before this function is called.
  */
 typedef void   (*GInterfaceInitFunc)         (gpointer         g_iface,
 					      gpointer         iface_data);
@@ -926,7 +933,7 @@ typedef void   (*GInterfaceFinalizeFunc)     (gpointer         g_iface,
  * whether they actually want to cache the class of this type, since all
  * classes are routed through the same #GTypeClassCacheFunc chain.
  * 
- * Returns: %TRUE to stop further #GTypeClassCacheFunc<!-- -->s from being 
+ * Returns: %TRUE to stop further #GTypeClassCacheFuncs from being 
  *  called, %FALSE to continue.
  */
 typedef gboolean (*GTypeClassCacheFunc)	     (gpointer	       cache_data,
@@ -987,11 +994,11 @@ typedef enum    /*< skip >*/
  *  and to do type-specific setup such as registering signals and object
  *  properties.
  * @class_finalize: Location of the class finalization function for
- *  classed and instantiatable types. Location fo the default vtable 
+ *  classed and instantiatable types. Location of the default vtable
  *  finalization function for interface types. (optional)
  * @class_data: User-supplied data passed to the class init/finalize functions.
  * @instance_size: Size of the instance (object) structure (required for instantiatable types only).
- * @n_preallocs: Prior to GLib 2.10, it specified the number of pre-allocated (cached) instances to reserve memory for (0 indicates no caching). Since GLib 2.10, it is ignored, since instances are allocated with the <link linkend="glib-Memory-Slices">slice allocator</link> now.
+ * @n_preallocs: Prior to GLib 2.10, it specified the number of pre-allocated (cached) instances to reserve memory for (0 indicates no caching). Since GLib 2.10, it is ignored, since instances are allocated with the [slice allocator][glib-Memory-Slices] now.
  * @instance_init: Location of the instance initialization function (optional, for instantiatable types only).
  * @value_table: A #GTypeValueTable function table for generic handling of GValues of this type (usually only
  *  useful for fundamental types).
@@ -1672,6 +1679,7 @@ static gint     TypeName##_private_offset; \
 \
 _G_DEFINE_TYPE_EXTENDED_CLASS_INIT(TypeName, type_name) \
 \
+G_GNUC_UNUSED \
 static inline gpointer \
 type_name##_get_instance_private (TypeName *self) \
 { \
